@@ -14,6 +14,7 @@
 #    under the License.
 #
 
+from neutronclient._i18n import _
 from neutronclient.neutron import v2_0 as neutronV20
 
 
@@ -28,8 +29,8 @@ class ListAgent(neutronV20.ListCommand):
     """List agents."""
 
     resource = 'agent'
-    list_columns = ['id', 'agent_type', 'host', 'alive', 'admin_state_up',
-                    'binary']
+    list_columns = ['id', 'agent_type', 'host', 'availability_zone', 'alive',
+                    'admin_state_up', 'binary']
     _formatters = {'heartbeat_timestamp': _format_timestamp}
     sorting_support = True
 
@@ -55,7 +56,23 @@ class DeleteAgent(neutronV20.DeleteCommand):
 
 
 class UpdateAgent(neutronV20.UpdateCommand):
-    """Update a given agent."""
+    """Updates the admin status and description for a specified agent."""
 
     resource = 'agent'
     allow_names = False
+
+    def add_known_arguments(self, parser):
+        parser.add_argument(
+            '--admin-state-down',
+            dest='admin_state',
+            action='store_false',
+            help=_('Set admin state up of the agent to false.'))
+        parser.add_argument(
+            '--description',
+            help=_('Description for the agent.'))
+
+    def args2body(self, parsed_args):
+        body = {'admin_state_up': parsed_args.admin_state}
+        neutronV20.update_dict(parsed_args, body,
+                               ['description'])
+        return {self.resource: body}
